@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -33,9 +34,7 @@
 //------------------------------------------------------------------------
 #include <osl/diagnose.h>
 
-#ifndef _TXDATAOBJECT_HXX_
 #include "XTDataObject.hxx"
-#endif
 #include <com/sun/star/datatransfer/dataflavor.hpp>
 #include "..\misc\ImplHelper.hxx"
 #include "DTransHelper.hxx"
@@ -846,3 +845,5 @@ STDMETHODIMP CEnumFormatEtc::Clone( IEnumFORMATETC** ppenum )
 
     return ( NULL != *ppenum ) ? S_OK : E_OUTOFMEMORY;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
