@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -25,6 +26,10 @@
  *
  ************************************************************************/
 
+#ifdef AIX
+#    undef _THREAD_SAFE
+#endif
+
 #include "HelpCompiler.hxx"
 
 #include <map>
@@ -58,7 +63,7 @@ private:
     xsltStylesheetPtr		m_xsltStylesheetPtrCaption;
     xsltStylesheetPtr		m_xsltStylesheetPtrContent;
 
-public: 
+public:
     IndexerPreProcessor( const std::string& aModuleName, const fs::path& fsIndexBaseDir,
          const fs::path& idxCaptionStylesheet, const fs::path& idxContentStylesheet );
     ~IndexerPreProcessor();
@@ -246,8 +251,8 @@ class HelpLinker
 public:
     void main(std::vector<std::string> &args,
 //		std::string* pExtensionPath = NULL, const rtl::OUString* pOfficeHelpPath = NULL )
-              std::string* pExtensionPath = NULL, 
-              std::string* pDestination = NULL, 
+              std::string* pExtensionPath = NULL,
+              std::string* pDestination = NULL,
               const rtl::OUString* pOfficeHelpPath = NULL )
 
             throw( HelpProcessingException );
@@ -269,6 +274,8 @@ private:
     fs::path idxContentStylesheet;
     fs::path zipdir;
     fs::path outputFile;
+    std::string extsource;
+    std::string extdestination;
     std::string module;
     std::string lang;
     std::string hid;
@@ -283,20 +290,8 @@ private:
     void initIndexerPreProcessor();
     void link() throw( HelpProcessingException );
     void addBookmark( DB* dbBase, FILE* pFile_DBHelp, std::string thishid,
-        const std::string& fileB, const std::string& anchorB, 
+        const std::string& fileB, const std::string& anchorB,
         const std::string& jarfileB, const std::string& titleB );
-#if 0
-    /**
-     * @param outputFile
-     * @param module
-     * @param lang
-     * @param hid
-     * @param helpFiles
-     * @param additionalFiles
-     */
-
-    private HelpURLStreamHandlerFactory urlHandler = null;
-#endif
 };
 
 namespace URLEncoder
@@ -305,7 +300,7 @@ namespace URLEncoder
     {
         const char *good = "!$&'()*+,-.=@_";
         static const char hex[17] = "0123456789ABCDEF";
-    
+
         std::string result;
         for (size_t i=0; i < rIn.length(); ++i)
         {
@@ -353,7 +348,7 @@ void HelpLinker::addBookmark( DB* dbBase, FILE* pFile_DBHelp, std::string thishi
     dataB[i++] = static_cast<unsigned char>(fileLen);
     for (size_t j = 0; j < fileB.length(); ++j)
         dataB[i++] = fileB[j];
-    if (!anchorB.empty()) 
+    if (!anchorB.empty())
     {
         dataB[i++] = '#';
         for (size_t j = 0; j < anchorB.length(); ++j)
@@ -393,7 +388,7 @@ void HelpLinker::initIndexerPreProcessor()
 }
 
 /**
-* 
+*
 */
 void HelpLinker::link() throw( HelpProcessingException )
 {
@@ -434,7 +429,7 @@ void HelpLinker::link() throw( HelpProcessingException )
 #ifndef DBHELP_ONLY
     fs::path helpTextFileName(indexDirParentName / (mod + ".ht"));
     db_create(&helpText,0,0);
-    helpText->open(helpText, NULL, helpTextFileName.native_file_string().c_str(), NULL, DB_BTREE, 
+    helpText->open(helpText, NULL, helpTextFileName.native_file_string().c_str(), NULL, DB_BTREE,
         DB_CREATE | DB_TRUNCATE, 0644);
 #endif
 
@@ -446,7 +441,7 @@ void HelpLinker::link() throw( HelpProcessingException )
 #ifndef DBHELP_ONLY
     fs::path dbBaseFileName(indexDirParentName / (mod + ".db"));
     db_create(&dbBase,0,0);
-    dbBase->open(dbBase, NULL, dbBaseFileName.native_file_string().c_str(), NULL, DB_BTREE, 
+    dbBase->open(dbBase, NULL, dbBaseFileName.native_file_string().c_str(), NULL, DB_BTREE,
         DB_CREATE | DB_TRUNCATE, 0644);
 #endif
 
@@ -458,7 +453,7 @@ void HelpLinker::link() throw( HelpProcessingException )
     DB* keyWord(0);
     fs::path keyWordFileName(indexDirParentName / (mod + ".key"));
     db_create(&keyWord,0,0);
-    keyWord->open(keyWord, NULL, keyWordFileName.native_file_string().c_str(), NULL, DB_BTREE, 
+    keyWord->open(keyWord, NULL, keyWordFileName.native_file_string().c_str(), NULL, DB_BTREE,
         DB_CREATE | DB_TRUNCATE, 0644);
 #endif
 
@@ -491,7 +486,7 @@ void HelpLinker::link() throw( HelpProcessingException )
     if( !bExtensionMode )
     {
 #ifndef OS2 // YD @TODO@ crashes libc runtime :-(
-        std::cout << "Making " << outputFile.native_file_string() << 
+        std::cout << "Making " << outputFile.native_file_string() <<
             " from " << helpFiles.size() << " input files" << std::endl;
 #endif
     }
@@ -505,7 +500,7 @@ void HelpLinker::link() throw( HelpProcessingException )
             std::cout << ".";
             std::cout.flush();
         }
-         
+
         // process one file
         // streamTable contains the streams in the hzip file
         StreamTable streamTable;
@@ -537,8 +532,8 @@ void HelpLinker::link() throw( HelpProcessingException )
             langsourceRoot.append('/' + lang + '/');
             xhpFile = fs::path(xhpFileName, fs::native);
         }
-         
-        HelpCompiler hc( streamTable, xhpFile, langsourceRoot, 
+
+        HelpCompiler hc( streamTable, xhpFile, langsourceRoot,
             embeddStylesheet, module, lang, bExtensionMode );
 
         HCDBG(std::cerr << "before compile of " << xhpFileName << std::endl);
@@ -548,7 +543,7 @@ void HelpLinker::link() throw( HelpProcessingException )
         if (!success && !bExtensionMode)
         {
             std::stringstream aStrStream;
-            aStrStream << 
+            aStrStream <<
                 "\nERROR: compiling help particle '"
                     << xhpFileName
                     << "' for language '"
@@ -568,13 +563,6 @@ void HelpLinker::link() throw( HelpProcessingException )
         if (documentTitle.empty())
             documentTitle = "<notitle>";
 
-#if 0
-        std::cout << "for " << xhpFileName << " documentBaseId is " << documentBaseId << "\n";
-        std::cout << "for " << xhpFileName << " documentPath is " << documentPath << "\n";
-        std::cout << "for " << xhpFileName << " documentJarfile is " << documentJarfile << "\n";
-        std::cout << "for " << xhpFileName << " documentPath is " << documentTitle << "\n";
-#endif
-
         const std::string& fileB = documentPath;
         const std::string& jarfileB = documentJarfile;
         std::string& titleB = documentTitle;
@@ -627,13 +615,13 @@ void HelpLinker::link() throw( HelpProcessingException )
                 // std::cerr << hzipFileName << std::endl;
                 const LinkedList& ll = enumer->second;
                 LinkedList::const_iterator aOtherEnd = ll.end();
-                for (LinkedList::const_iterator llIter = ll.begin(); 
+                for (LinkedList::const_iterator llIter = ll.begin();
                     llIter != aOtherEnd; ++llIter)
                 {
                         helpKeyword.insert(*llIter, totalId);
                 }
             }
-                
+
         }
 
         // and last the helptexts
@@ -686,7 +674,7 @@ void HelpLinker::link() throw( HelpProcessingException )
             if (document)
             {
                 std::string temp = module;
-                std::transform (temp.begin(), temp.end(), temp.begin(), tolower); 
+                std::transform (temp.begin(), temp.end(), temp.begin(), tolower);
                 m_pIndexerPreProcessor->processDocument(document, URLEncoder::encode(documentPath) );
             }
         }
@@ -758,22 +746,13 @@ void HelpLinker::link() throw( HelpProcessingException )
 
 
 void HelpLinker::main( std::vector<std::string> &args,
-                       std::string* pExtensionPath, std::string* pDestination,  
+                       std::string* pExtensionPath, std::string* pDestination,
                        const rtl::OUString* pOfficeHelpPath )
     throw( HelpProcessingException )
 {
-    rtl::OUString aOfficeHelpPath;
-
     bExtensionMode = false;
-    if( pExtensionPath && pExtensionPath->length() > 0 && pOfficeHelpPath )
-    {
-        helpFiles.clear();
-        bExtensionMode = true;
-        extensionPath = *pExtensionPath;
-        sourceRoot = fs::path(extensionPath);
-        extensionDestination = *pDestination;
-        aOfficeHelpPath = *pOfficeHelpPath;
-    }
+    helpFiles.clear();
+
     if (args.size() > 0 && args[0][0] == '@')
     {
         std::vector<std::string> stringList;
@@ -793,23 +772,46 @@ void HelpLinker::main( std::vector<std::string> &args,
     }
 
     size_t i = 0;
-
+    bool bSrcOption = false;
     while (i < args.size())
     {
-        if (args[i].compare("-src") == 0)
+        if (args[i].compare("-extlangsrc") == 0)
         {
             ++i;
-            if (i >= args.size()) 
+            if (i >= args.size())
+            {
+                std::stringstream aStrStream;
+                aStrStream << "extension source missing" << std::endl;
+                throw HelpProcessingException( HELPPROCESSING_GENERAL_ERROR, aStrStream.str() );
+            }
+            extsource = args[i];
+        }
+        else if (args[i].compare("-extlangdest") == 0)
+        {
+            //If this argument is not provided then the location provided in -extsource will
+            //also be the destination
+            ++i;
+            if (i >= args.size())
+            {
+                std::stringstream aStrStream;
+                aStrStream << "extension destination missing" << std::endl;
+                throw HelpProcessingException( HELPPROCESSING_GENERAL_ERROR, aStrStream.str() );
+            }
+            extdestination = args[i];
+        }
+        else if (args[i].compare("-src") == 0)
+        {
+            ++i;
+            if (i >= args.size())
             {
                 std::stringstream aStrStream;
                 aStrStream << "sourceroot missing" << std::endl;
                 throw HelpProcessingException( HELPPROCESSING_GENERAL_ERROR, aStrStream.str() );
             }
-
-            if( !bExtensionMode )
-                sourceRoot = fs::path(args[i], fs::native);
+            bSrcOption = true;
+            sourceRoot = fs::path(args[i], fs::native);
         }
-        else if (args[i].compare("-sty") == 0) 
+        else if (args[i].compare("-sty") == 0)
         {
             ++i;
             if (i >= args.size())
@@ -820,11 +822,11 @@ void HelpLinker::main( std::vector<std::string> &args,
             }
 
             embeddStylesheet = fs::path(args[i], fs::native);
-        } 
-        else if (args[i].compare("-zipdir") == 0) 
+        }
+        else if (args[i].compare("-zipdir") == 0)
         {
             ++i;
-            if (i >= args.size()) 
+            if (i >= args.size())
             {
                 std::stringstream aStrStream;
                 aStrStream << "idxtemp missing" << std::endl;
@@ -832,11 +834,11 @@ void HelpLinker::main( std::vector<std::string> &args,
             }
 
             zipdir = fs::path(args[i], fs::native);
-        } 
-        else if (args[i].compare("-idxcaption") == 0) 
+        }
+        else if (args[i].compare("-idxcaption") == 0)
         {
             ++i;
-            if (i >= args.size()) 
+            if (i >= args.size())
             {
                 std::stringstream aStrStream;
                 aStrStream << "idxcaption stylesheet missing" << std::endl;
@@ -844,11 +846,11 @@ void HelpLinker::main( std::vector<std::string> &args,
             }
 
             idxCaptionStylesheet = fs::path(args[i], fs::native);
-        } 
-        else if (args[i].compare("-idxcontent") == 0) 
+        }
+        else if (args[i].compare("-idxcontent") == 0)
         {
             ++i;
-            if (i >= args.size()) 
+            if (i >= args.size())
             {
                 std::stringstream aStrStream;
                 aStrStream << "idxcontent stylesheet missing" << std::endl;
@@ -868,8 +870,8 @@ void HelpLinker::main( std::vector<std::string> &args,
             }
 
             outputFile = fs::path(args[i], fs::native);
-        } 
-        else if (args[i].compare("-mod") == 0) 
+        }
+        else if (args[i].compare("-mod") == 0)
         {
             ++i;
             if (i >= args.size())
@@ -880,7 +882,7 @@ void HelpLinker::main( std::vector<std::string> &args,
             }
 
             module = args[i];
-        } 
+        }
         else if (args[i].compare("-lang") == 0)
         {
             ++i;
@@ -892,7 +894,7 @@ void HelpLinker::main( std::vector<std::string> &args,
             }
 
             lang = args[i];
-        } 
+        }
         else if (args[i].compare("-hid") == 0)
         {
             ++i;
@@ -904,7 +906,7 @@ void HelpLinker::main( std::vector<std::string> &args,
             }
 
             hid = args[i];
-        } 
+        }
         else if (args[i].compare("-add") == 0)
         {
             std::string addFile, addFileUnderPath;
@@ -928,26 +930,75 @@ void HelpLinker::main( std::vector<std::string> &args,
             if (!addFileUnderPath.empty() && !addFile.empty())
                 additionalFiles[addFileUnderPath] = addFile;
         }
-        else 
+        else
             helpFiles.push_back(args[i]);
         ++i;
     }
 
+    //We can be called from the helplinker executable or the extension manager
+    //In the latter case extsource is not used.
+    if( (pExtensionPath && pExtensionPath->length() > 0 && pOfficeHelpPath)
+        || !extsource.empty())
+    {
+        bExtensionMode = true;
+        if (!extsource.empty())
+        {
+            //called from helplinker.exe, pExtensionPath and pOfficeHelpPath
+            //should be NULL
+            sourceRoot = fs::path(extsource, fs::native);
+            extensionPath = sourceRoot.toUTF8();
+
+            if (extdestination.empty())
+            {
+                std::stringstream aStrStream;
+                aStrStream << "-extlangdest is missing" << std::endl;
+                throw HelpProcessingException( HELPPROCESSING_GENERAL_ERROR, aStrStream.str() );
+            }
+            else
+            {
+                //Convert from system path to file URL!!!
+                fs::path p(extdestination, fs::native);
+                extensionDestination = p.toUTF8();
+            }
+        }
+        else
+        { //called from extension manager
+            extensionPath = *pExtensionPath;
+            sourceRoot = fs::path(extensionPath);
+            extensionDestination = *pDestination;
+        }
+        //check if -src option was used. This option must not be used
+        //when extension help is compiled.
+        if (bSrcOption)
+        {
+            std::stringstream aStrStream;
+            aStrStream << "-src must not be used together with -extsource missing" << std::endl;
+            throw HelpProcessingException( HELPPROCESSING_GENERAL_ERROR, aStrStream.str() );
+        }
+    }
+
     if (!bExtensionMode && zipdir.empty())
     {
         std::stringstream aStrStream;
         aStrStream << "no index dir given" << std::endl;
         throw HelpProcessingException( HELPPROCESSING_GENERAL_ERROR, aStrStream.str() );
     }
-    if (!bExtensionMode && idxCaptionStylesheet.empty())
+
+    if ( (!bExtensionMode && idxCaptionStylesheet.empty())
+        || (!extsource.empty() && idxCaptionStylesheet.empty()) )
     {
+        //No extension mode and extension mode using commandline
+        //!extsource.empty indicates extension mode using commandline
+        // -idxcaption paramter is required
         std::stringstream aStrStream;
         aStrStream << "no index caption stylesheet given" << std::endl;
         throw HelpProcessingException( HELPPROCESSING_GENERAL_ERROR, aStrStream.str() );
     }
-    else if ( bExtensionMode )
+    else if ( bExtensionMode &&  extsource.empty())
     {
-        rtl::OUString aIdxCaptionPathFileURL( aOfficeHelpPath );
+        //This part is used when compileExtensionHelp is called from the extensions manager.
+        //If extension help is compiled using helplinker in the build process
+        rtl::OUString aIdxCaptionPathFileURL( *pOfficeHelpPath );
         aIdxCaptionPathFileURL += rtl::OUString::createFromAscii( "/idxcaption.xsl" );
 
         rtl::OString aOStr_IdxCaptionPathFileURL( rtl::OUStringToOString
@@ -956,15 +1007,23 @@ void HelpLinker::main( std::vector<std::string> &args,
 
         idxCaptionStylesheet = fs::path( aStdStr_IdxCaptionPathFileURL );
     }
-    if (!bExtensionMode && idxContentStylesheet.empty())
+
+    if ( (!bExtensionMode && idxContentStylesheet.empty())
+        || (!extsource.empty() && idxContentStylesheet.empty()) )
     {
+        //No extension mode and extension mode using commandline
+        //!extsource.empty indicates extension mode using commandline
+        // -idxcontent paramter is required
         std::stringstream aStrStream;
         aStrStream << "no index content stylesheet given" << std::endl;
         throw HelpProcessingException( HELPPROCESSING_GENERAL_ERROR, aStrStream.str() );
     }
-    else if ( bExtensionMode )
+    else if ( bExtensionMode && extsource.empty())
     {
-        rtl::OUString aIdxContentPathFileURL( aOfficeHelpPath );
+        //If extension help is compiled using helplinker in the build process
+        //then  -idxcontent must be supplied
+        //This part is used when compileExtensionHelp is called from the extensions manager.
+        rtl::OUString aIdxContentPathFileURL( *pOfficeHelpPath );
         aIdxContentPathFileURL += rtl::OUString::createFromAscii( "/idxcontent.xsl" );
 
         rtl::OString aOStr_IdxContentPathFileURL( rtl::OUStringToOString
@@ -1054,7 +1113,7 @@ extern "C" void StructuredXMLErrorFunction(void *userData, xmlErrorPtr error)
     GpXMLParsingException = pException;
 
     // Reset error handler
-    xmlSetStructuredErrorFunc( NULL, NULL ); 
+    xmlSetStructuredErrorFunc( NULL, NULL );
 }
 
 HelpProcessingErrorInfo& HelpProcessingErrorInfo::operator=( const struct HelpProcessingException& e )
@@ -1082,31 +1141,20 @@ HELPLINKER_DLLPUBLIC bool compileExtensionHelp
 {
     bool bSuccess = true;
 
-    sal_Int32 argc = nXhpFileCount + 3;
-    const char** argv = new const char*[argc];
-    argv[0] = "";
-    argv[1] = "-mod";
+    std::vector<std::string> args;
+    args.reserve(nXhpFileCount + 2);
+    args.push_back(std::string("-mod"));
     rtl::OString aOExtensionName = rtl::OUStringToOString( aExtensionName, fs::getThreadTextEncoding() );
-    argv[2] = aOExtensionName.getStr();
+    args.push_back(std::string(aOExtensionName.getStr()));
 
     for( sal_Int32 iXhp = 0 ; iXhp < nXhpFileCount ; ++iXhp )
     {
         rtl::OUString aXhpFile = pXhpFiles[iXhp];
 
         rtl::OString aOXhpFile = rtl::OUStringToOString( aXhpFile, fs::getThreadTextEncoding() );
-        char* pArgStr = new char[aOXhpFile.getLength() + 1];
-        strcpy( pArgStr, aOXhpFile.getStr() );
-        argv[iXhp + 3] = pArgStr;
+        args.push_back(std::string(aOXhpFile.getStr()));
     }
 
-    std::vector<std::string> args;
-    for( sal_Int32 i = 1; i < argc; ++i )
-        args.push_back(std::string( argv[i]) );
-
-    for( sal_Int32 iXhp = 0 ; iXhp < nXhpFileCount ; ++iXhp )
-        delete[] argv[iXhp + 3];
-    delete[] argv;
-
     rtl::OString aOExtensionLanguageRoot = rtl::OUStringToOString( aExtensionLanguageRoot, fs::getThreadTextEncoding() );
     const char* pExtensionPath = aOExtensionLanguageRoot.getStr();
     std::string aStdStrExtensionPath = pExtensionPath;
@@ -1115,7 +1163,7 @@ HELPLINKER_DLLPUBLIC bool compileExtensionHelp
     std::string aStdStrDestination = pDestination;
 
     // Set error handler
-    xmlSetStructuredErrorFunc( NULL, (xmlStructuredErrorFunc)StructuredXMLErrorFunction ); 
+    xmlSetStructuredErrorFunc( NULL, (xmlStructuredErrorFunc)StructuredXMLErrorFunction );
     try
     {
         HelpLinker* pHelpLinker = new HelpLinker();
@@ -1137,7 +1185,7 @@ HELPLINKER_DLLPUBLIC bool compileExtensionHelp
         bSuccess = false;
     }
     // Reset error handler
-    xmlSetStructuredErrorFunc( NULL, NULL ); 
+    xmlSetStructuredErrorFunc( NULL, NULL );
 
     // i83624: Tree files
     ::rtl::OUString aTreeFileURL = aExtensionLanguageRoot;
@@ -1146,7 +1194,7 @@ HELPLINKER_DLLPUBLIC bool compileExtensionHelp
     osl::FileBase::RC rcGet = osl::DirectoryItem::get( aTreeFileURL, aTreeFileItem );
     osl::FileStatus aFileStatus( FileStatusMask_FileSize );
     if( rcGet == osl::FileBase::E_None &&
-        aTreeFileItem.getFileStatus( aFileStatus ) == osl::FileBase::E_None && 
+        aTreeFileItem.getFileStatus( aFileStatus ) == osl::FileBase::E_None &&
         aFileStatus.isValid( FileStatusMask_FileSize ) )
     {
         sal_uInt64 ret, len = aFileStatus.getFileSize();
@@ -1169,7 +1217,7 @@ HELPLINKER_DLLPUBLIC bool compileExtensionHelp
             bSuccess = false;
         }
 
-        XML_ParserFree( parser );		
+        XML_ParserFree( parser );
         delete[] s;
     }
 
@@ -1177,5 +1225,5 @@ HELPLINKER_DLLPUBLIC bool compileExtensionHelp
 }
 
 // vnd.sun.star.help://swriter/52821?Language=en-US&System=UNIX
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
