@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -50,8 +51,7 @@
 #include <cppuhelper/implbase1.hxx>
 #include <cppuhelper/implbase3.hxx>
 
-#include <vos/dynload.hxx>
-#include <vos/diagnose.hxx>
+#include <osl/diagnose.h>
 
 using namespace ::rtl;
 using namespace ::std;
@@ -649,3 +649,5 @@ int main (int argc, char **argv)
         printf( "couln't create sax-writer component\n" );
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
