@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,6 +32,7 @@
 // include ---------------------------------------------------------------
 
 #include <svl/srchitem.hxx>
+#include <sal/macros.h>
 
 #include <unotools/searchopt.hxx>
 #include <com/sun/star/util/XReplaceable.hpp>
@@ -51,7 +53,7 @@ using namespace com::sun::star::util;
 
 #define CFG_ROOT_NODE       "Office.Common/SearchOptions"
 
-#define SRCH_PARAMS         11
+#define SRCH_PARAMS         12
 #define SRCH_PARA_OPTIONS   "Options"
 #define SRCH_PARA_FAMILY    "Family"
 #define SRCH_PARA_COMMAND   "Command"
@@ -59,6 +61,7 @@ using namespace com::sun::star::util;
 #define SRCH_PARA_APPFLAG   "AppFlag"
 #define SRCH_PARA_ROWDIR    "RowDirection"
 #define SRCH_PARA_ALLTABLES "AllTables"
+#define SRCH_PARA_SEARCHFILTERED "SearchFiltered"
 #define SRCH_PARA_BACKWARD  "Backward"
 #define SRCH_PARA_PATTERN   "Pattern"
 #define SRCH_PARA_CONTENT   "Content"
@@ -96,7 +99,7 @@ static Sequence< ::rtl::OUString > lcl_GetNotifyNames()
         "Japanese/IsIgnoreMiddleDot"			// 18
     };
 
-    const int nCount = sizeof( aTranslitNames ) / sizeof( aTranslitNames[0] );
+    const int nCount = SAL_N_ELEMENTS( aTranslitNames );
     Sequence< ::rtl::OUString > aNames( nCount );
     ::rtl::OUString* pNames = aNames.getArray();
     for (INT32 i = 0;  i < nCount;  ++i)
@@ -124,6 +127,7 @@ SvxSearchItem::SvxSearchItem( const sal_uInt16 nId ) :
     nAppFlag		( SVX_SEARCHAPP_WRITER ),
     bRowDirection	( sal_True ),
     bAllTables		( sal_False ),
+    bSearchFiltered   ( sal_False ),
     bNotes			( sal_False),
     bBackward		( sal_False ),
     bPattern		( sal_False ),
@@ -205,6 +209,7 @@ SvxSearchItem::SvxSearchItem( const SvxSearchItem& rItem ) :
     nAppFlag		( rItem.nAppFlag ),
     bRowDirection	( rItem.bRowDirection ),
     bAllTables		( rItem.bAllTables ),
+    bSearchFiltered   ( rItem.bSearchFiltered ),
     bNotes			( rItem.bNotes),
     bBackward		( rItem.bBackward ),
     bPattern		( rItem.bPattern ),
@@ -254,6 +259,7 @@ int SvxSearchItem::operator==( const SfxPoolItem& rItem ) const
            ( eFamily 		== rSItem.eFamily )			&&
            ( bRowDirection 	== rSItem.bRowDirection )	&&
            ( bAllTables 	== rSItem.bAllTables )		&&
+           ( bSearchFiltered  == rSItem.bSearchFiltered )   &&
            ( nCellType 		== rSItem.nCellType )		&&
            ( nAppFlag 		== rSItem.nAppFlag )		&&
            ( bAsianOptions	== rSItem.bAsianOptions )	&&
@@ -425,7 +431,7 @@ void SvxSearchItem::SetTransliterationFlags( sal_Int32 nFlags )
     aSearchOpt.transliterateFlags = nFlags;
 }
 
-sal_Bool SvxSearchItem::QueryValue( com::sun::star::uno::Any& rVal, BYTE nMemberId ) const
+bool SvxSearchItem::QueryValue( com::sun::star::uno::Any& rVal, BYTE nMemberId ) const
 {
     nMemberId &= ~CONVERT_TWIPS;
     switch ( nMemberId )
@@ -447,6 +453,8 @@ sal_Bool SvxSearchItem::QueryValue( com::sun::star::uno::Any& rVal, BYTE nMember
             aSeq[5].Value <<= bRowDirection;
             aSeq[6].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( SRCH_PARA_ALLTABLES ));
             aSeq[6].Value <<= bAllTables;
+            aSeq[6].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( SRCH_PARA_SEARCHFILTERED ));
+            aSeq[6].Value <<= bSearchFiltered;
             aSeq[7].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( SRCH_PARA_BACKWARD ));
             aSeq[7].Value <<= bBackward;
             aSeq[8].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( SRCH_PARA_PATTERN ));
@@ -468,6 +476,8 @@ sal_Bool SvxSearchItem::QueryValue( com::sun::star::uno::Any& rVal, BYTE nMember
             rVal <<= (sal_Bool) bRowDirection; break;
         case MID_SEARCH_ALLTABLES:
             rVal <<= (sal_Bool) bAllTables; break;
+        case MID_SEARCH_SEARCHFILTERED:
+            rVal <<= (sal_Bool) bSearchFiltered; break;
         case MID_SEARCH_BACKWARD:
             rVal <<= (sal_Bool) bBackward; break;
         case MID_SEARCH_PATTERN:
@@ -505,18 +515,18 @@ sal_Bool SvxSearchItem::QueryValue( com::sun::star::uno::Any& rVal, BYTE nMember
 
         default:
             DBG_ERRORFILE( "SvxSearchItem::QueryValue(): Unknown MemberId" );
-            return sal_False;
+            return false;
     }
 
-    return sal_True;
+    return true;
 }
 
 // -----------------------------------------------------------------------
 
-sal_Bool SvxSearchItem::PutValue( const com::sun::star::uno::Any& rVal, BYTE nMemberId )
+bool SvxSearchItem::PutValue( const com::sun::star::uno::Any& rVal, BYTE nMemberId )
 {
     nMemberId &= ~CONVERT_TWIPS;
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
     sal_Int32 nInt = 0;
     switch ( nMemberId )
     {
@@ -567,6 +577,11 @@ sal_Bool SvxSearchItem::PutValue( const com::sun::star::uno::Any& rVal, BYTE nMe
                         if ( ( aSeq[i].Value >>= bAllTables ) == sal_True )
                             ++nConvertedCount;
                     }
+                    else if ( aSeq[i].Name.equalsAscii( SRCH_PARA_SEARCHFILTERED ) )
+                    {
+                        if ( ( aSeq[i].Value >>= bSearchFiltered ) == sal_True )
+                            ++nConvertedCount;
+                    }
                     else if ( aSeq[i].Name.equalsAscii( SRCH_PARA_BACKWARD ) )
                     {
                         if ( ( aSeq[i].Value >>= bBackward ) == sal_True )
@@ -603,6 +618,8 @@ sal_Bool SvxSearchItem::PutValue( const com::sun::star::uno::Any& rVal, BYTE nMe
             bRet = (rVal >>= bRowDirection); break;
         case MID_SEARCH_ALLTABLES:
             bRet = (rVal >>= bAllTables); break;
+        case MID_SEARCH_SEARCHFILTERED:
+            bRet = (rVal >>= bSearchFiltered); break;
         case MID_SEARCH_BACKWARD:
             bRet = (rVal >>= bBackward); break;
         case MID_SEARCH_PATTERN:
@@ -651,3 +668,4 @@ sal_Bool SvxSearchItem::PutValue( const com::sun::star::uno::Any& rVal, BYTE nMe
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
