@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -78,14 +79,18 @@ using namespace ::com::sun::star;
 #define PROPERTYHANDLE_SYMBOLSTYLE			4
 #define PROPERTYNAME_USESYSTEMPRINTDIALOG	ASCII_STR("UseSystemPrintDialog")
 #define PROPERTYHANDLE_USESYSTEMPRINTDIALOG	5
-#define PROPERTYNAME_TRYODMADIALOG	ASCII_STR("TryODMADialog")
-#define PROPERTYHANDLE_TRYODMADIALOG	6
+#define PROPERTYNAME_TRYODMADIALOG          ASCII_STR("TryODMADialog")
+#define PROPERTYHANDLE_TRYODMADIALOG        6
 #define PROPERTYNAME_SHOWLINKWARNINGDIALOG	ASCII_STR("ShowLinkWarningDialog")
 #define PROPERTYHANDLE_SHOWLINKWARNINGDIALOG 7
 #define PROPERTYNAME_DISABLEUICUSTOMIZATION	ASCII_STR("DisableUICustomization")
 #define PROPERTYHANDLE_DISABLEUICUSTOMIZATION			8
+#define PROPERTYNAME_ALWAYSALLOWSAVE        ASCII_STR("AlwaysAllowSave")
+#define PROPERTYHANDLE_ALWAYSALLOWSAVE      9
+#define PROPERTYNAME_EXPERIMENTALMODE       ASCII_STR("ExperimentalMode")
+#define PROPERTYHANDLE_EXPERIMENTALMODE     10
 
-#define PROPERTYCOUNT						9
+#define PROPERTYCOUNT                       11
 
 #define VCL_TOOLBOX_STYLE_FLAT				((USHORT)0x0004) // from <vcl/toolbox.hxx>
 
@@ -119,6 +124,8 @@ class SvtMiscOptions_Impl : public ConfigItem
     sal_Bool    m_bShowLinkWarningDialog;
     sal_Bool    m_bIsShowLinkWarningDialogRO;
     sal_Bool    m_bDisableUICustomization;
+    sal_Bool    m_bAlwaysAllowSave;
+    sal_Bool    m_bExperimentalMode;
 
     //-------------------------------------------------------------------------------------------------------------
     //	public methods
@@ -199,6 +206,18 @@ class SvtMiscOptions_Impl : public ConfigItem
         inline sal_Bool DisableUICustomization() const
         { return m_bDisableUICustomization; }
 
+        inline void SetSaveAlwaysAllowed( sal_Bool bSet )
+        { m_bAlwaysAllowSave = bSet; SetModified(); }
+
+        inline sal_Bool IsSaveAlwaysAllowed() const
+        { return m_bAlwaysAllowSave; }
+
+        inline void SetExperimentalMode( sal_Bool bSet )
+        { m_bExperimentalMode = bSet; SetModified(); }
+
+        inline sal_Bool IsExperimentalMode() const
+        { return m_bExperimentalMode; }
+
         inline sal_Bool IsPluginsEnabled() const
         { return m_bPluginsEnabled; }
 
@@ -307,6 +326,8 @@ SvtMiscOptions_Impl::SvtMiscOptions_Impl()
     , m_bIsUseSystemPrintDialogRO( sal_False )
     , m_bShowLinkWarningDialog( sal_True )
     , m_bIsShowLinkWarningDialogRO( sal_False )
+    , m_bAlwaysAllowSave( sal_False )
+    , m_bExperimentalMode( sal_False )
 
 {
     // Use our static list of configuration keys to get his values.
@@ -416,7 +437,19 @@ SvtMiscOptions_Impl::SvtMiscOptions_Impl()
             {
                 if( !(seqValues[nProperty] >>= m_bDisableUICustomization) )
                     DBG_ERROR("Wrong type of \"Misc\\DisableUICustomization\"!" );
-                    break;
+                break;
+            }
+            case PROPERTYHANDLE_ALWAYSALLOWSAVE :
+            {
+                if( !(seqValues[nProperty] >>= m_bAlwaysAllowSave) )
+                    DBG_ERROR("Wrong type of \"Misc\\AlwaysAllowSave\"!" );
+                break;
+            }
+            case PROPERTYHANDLE_EXPERIMENTALMODE :
+            {
+                if( !(seqValues[nProperty] >>= m_bExperimentalMode) )
+                    DBG_ERROR("Wrong type of \"Misc\\ExperimentalMode\"!" );
+                break;
             }
         }
     }
@@ -538,6 +571,12 @@ void SvtMiscOptions_Impl::Load( const Sequence< OUString >& rPropertyNames )
                                                                 DBG_ERROR("Wrong type of \"Misc\\DisableUICustomization\"!" );
                                                         }
                                                     break;
+            case PROPERTYHANDLE_ALWAYSALLOWSAVE:
+            {
+                if( !(seqValues[nProperty] >>= m_bAlwaysAllowSave) )
+                    DBG_ERROR("Wrong type of \"Misc\\AlwaysAllowSave\"!" );
+            }
+            break;
         }
     }
 }
@@ -707,6 +746,16 @@ void SvtMiscOptions_Impl::Commit()
                 seqValues[nProperty] <<= m_bDisableUICustomization;
                 break;
             }
+            case PROPERTYHANDLE_ALWAYSALLOWSAVE :
+            {
+                seqValues[nProperty] <<= m_bAlwaysAllowSave;
+                break;
+            }
+            case PROPERTYHANDLE_EXPERIMENTALMODE :
+            {
+                seqValues[nProperty] <<= m_bExperimentalMode;
+                break;
+            }
         }
     }
     // Set properties in configuration.
@@ -729,11 +778,13 @@ Sequence< OUString > SvtMiscOptions_Impl::GetPropertyNames()
         PROPERTYNAME_USESYSTEMPRINTDIALOG,
         PROPERTYNAME_TRYODMADIALOG,
         PROPERTYNAME_SHOWLINKWARNINGDIALOG,
-        PROPERTYNAME_DISABLEUICUSTOMIZATION
+        PROPERTYNAME_DISABLEUICUSTOMIZATION,
+        PROPERTYNAME_ALWAYSALLOWSAVE,
+        PROPERTYNAME_EXPERIMENTALMODE
     };
 
     // Initialize return sequence with these list ...
-    static const Sequence< OUString > seqPropertyNames( pProperties, PROPERTYCOUNT );
+    static const Sequence< OUString > seqPropertyNames( pProperties, SAL_N_ELEMENTS( pProperties ) );
     // ... and return it.
     return seqPropertyNames;
 }
@@ -935,6 +986,26 @@ sal_Bool SvtMiscOptions::IsShowLinkWarningDialogReadOnly() const
     return m_pDataContainer->IsShowLinkWarningDialogReadOnly();
 }
 
+void SvtMiscOptions::SetSaveAlwaysAllowed( sal_Bool bSet )
+{
+    m_pDataContainer->SetSaveAlwaysAllowed( bSet );
+}
+
+sal_Bool SvtMiscOptions::IsSaveAlwaysAllowed() const
+{
+    return m_pDataContainer->IsSaveAlwaysAllowed();
+}
+
+void SvtMiscOptions::SetExperimentalMode( sal_Bool bSet )
+{
+    m_pDataContainer->SetExperimentalMode( bSet );
+}
+
+sal_Bool SvtMiscOptions::IsExperimentalMode() const
+{
+    return m_pDataContainer->IsExperimentalMode();
+}
+
 //*****************************************************************************************************************
 //	private method
 //*****************************************************************************************************************
@@ -969,3 +1040,5 @@ void SvtMiscOptions::RemoveListenerLink( const Link& rLink )
 {
     m_pDataContainer->RemoveListenerLink( rLink );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
