@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,9 +29,6 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_svtools.hxx"
 
-#ifndef GCC
-#endif
-
 #include "ivctrl.hxx"
 #include "imivctl.hxx"
 #include <vcl/bitmapex.hxx>
@@ -640,3 +638,4 @@ void SvtIconChoiceCtrl::CallImplEventListeners(ULONG nEvent, void* pData)
     return xAccessible;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
