@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -42,26 +43,18 @@
 #include <com/sun/star/sdbc/XResultSet.hpp>
 #include <com/sun/star/sdbc/XRow.hpp>
 
-#ifndef  _COM_SUN_STAR_TASK_XINTERACTIONHANDLER_HDL_
 #include <com/sun/star/task/XInteractionHandler.hdl>
-#endif
 #include <com/sun/star/ucb/NumberedSortingInfo.hpp>
 #include <com/sun/star/ucb/XAnyCompareFactory.hpp>
 #include <com/sun/star/ucb/XProgressHandler.hpp>
 #include <com/sun/star/ucb/XContentAccess.hpp>
 #include <com/sun/star/ucb/XSortedDynamicResultSetFactory.hpp>
 
-#ifndef _UNOTOOLS_PROCESSFACTORY_HXX
 #include <comphelper/processfactory.hxx>
-#endif
 
 #include <vcl/toolbox.hxx>
-#ifndef _VOS_THREAD_HXX //autogen
-#include <vos/thread.hxx>
-#endif
-#ifndef _VOS_MUTEX_HXX //autogen
-#include <vos/mutex.hxx>
-#endif
+#include <osl/thread.hxx>
+#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 #include <unotools/historyoptions.hxx>
 #include <svl/eitem.hxx>
@@ -118,9 +111,9 @@ public:
 };
 
 // -----------------------------------------------------------------------
-class SvtMatchContext_Impl : public ::vos::OThread
+class SvtMatchContext_Impl : public ::osl::Thread
 {
-    static ::vos::OMutex*           pDirMutex;
+    static ::osl::Mutex*            pDirMutex;
 
     SvStringsDtor 					aPickList;
     SvStringsDtor*                  pCompletions;
@@ -143,20 +136,20 @@ class SvtMatchContext_Impl : public ::vos::OThread
     void                            FillPicklist( SvStringsDtor& rPickList );
 
 public:
-    static ::vos::OMutex*           GetMutex();
+    static ::osl::Mutex*           GetMutex();
 
                                     SvtMatchContext_Impl( SvtURLBox* pBoxP, const String& rText );
                                     ~SvtMatchContext_Impl();
     void          					Stop();
 };
 
-::vos::OMutex* SvtMatchContext_Impl::pDirMutex = 0;
+::osl::Mutex* SvtMatchContext_Impl::pDirMutex = 0;
 
-::vos::OMutex* SvtMatchContext_Impl::GetMutex()
+::osl::Mutex* SvtMatchContext_Impl::GetMutex()
 {
-    ::vos::OGuard aGuard( ::vos::OMutex::getGlobalMutex() );
+    ::osl::MutexGuard aGuard( ::osl::Mutex::getGlobalMutex() );
     if( !pDirMutex )
-        pDirMutex = new ::vos::OMutex;
+        pDirMutex = new ::osl::Mutex;
     return pDirMutex;
 }
 
@@ -608,7 +601,7 @@ String SvtURLBox::ParseSmart( String aText, String aBaseURL, String aWorkDir )
 //-------------------------------------------------------------------------
 void SvtMatchContext_Impl::run()
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    ::osl::MutexGuard aGuard( GetMutex() );
     if( bStop )
         // have we been stopped while we were waiting for the mutex?
         return;
@@ -984,7 +977,7 @@ BOOL SvtURLBox::ProcessKey( const KeyCode& rKey )
     if ( aCode == KEY_RETURN && GetText().Len() )
     {
         // wait for completion of matching thread
-        ::vos::OGuard aGuard( SvtMatchContext_Impl::GetMutex() );
+        ::osl::MutexGuard aGuard( SvtMatchContext_Impl::GetMutex() );
 
         if ( bAutoCompleteMode )
         {
@@ -1150,7 +1143,7 @@ void SvtURLBox::SetNoURLSelection( BOOL bSet )
 String SvtURLBox::GetURL()
 {
     // wait for end of autocompletion
-    ::vos::OGuard aGuard( SvtMatchContext_Impl::GetMutex() );
+    ::osl::MutexGuard aGuard( SvtMatchContext_Impl::GetMutex() );
 
     String aText( GetText() );
     if ( MatchesPlaceHolder( aText ) )
@@ -1246,7 +1239,7 @@ void SvtURLBox::DisableHistory()
 //-------------------------------------------------------------------------
 void SvtURLBox::SetBaseURL( const String& rURL )
 {
-    ::vos::OGuard aGuard( SvtMatchContext_Impl::GetMutex() );
+    ::osl::MutexGuard aGuard( SvtMatchContext_Impl::GetMutex() );
 
     // Reset match lists
     if ( pImp->pCompletions )
@@ -1373,3 +1366,4 @@ void SvtURLBox::SetFilter(const String& _sFilter)
     FilterMatch::createWildCardFilterList(_sFilter,pImp->m_aFilters);
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
