@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,14 +31,10 @@
 
 #define _TASKBAR_CXX
 
-#ifndef _TOOLS_LIST_HXX
 #include <tools/list.hxx>
-#endif
 #include <tools/debug.hxx>
 
-#ifndef _VCL_FLOATWIN_HXX
 #include <vcl/floatwin.hxx>
-#endif
 
 #include <taskbar.hxx>
 
@@ -592,3 +589,5 @@ TaskStatusBar* TaskBar::GetStatusBar() const
     }
     return mpStatusBar;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
