@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,12 +32,8 @@
 #include <tools/debug.hxx>
 #include <vcl/decoview.hxx>
 #include <vcl/svapp.hxx>
-#ifndef _SCRBAR_HXX
 #include <vcl/scrbar.hxx>
-#endif
-#ifndef _HELP_HXX
 #include <vcl/help.hxx>
-#endif
 #include <com/sun/star/accessibility/AccessibleEventObject.hpp>
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
@@ -1568,16 +1565,6 @@ void ValueSet::KeyInput( const KeyEvent& rKEvt )
                             nCalcPos + ( nLineCount * mnCols ));
                     else
                     {
-#if 0
-                        if( (KEY_DOWN == rKEvt.GetKeyCode().GetCode() ) && (GetStyle() & WB_MENUSTYLEVALUESET) )
-                        {
-                            Window* pParent = GetParent();
-                            pParent->GrabFocus();
-                            pParent->KeyInput( rKEvt );
-                            break;
-                        }
-                        else
-#endif
                         {
                             if ( mpNoneItem )
                             {
@@ -2756,3 +2743,4 @@ const Link& ValueSet::GetHighlightHdl() const
 
 // -----------------------------------------------------------------------
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
