@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -36,9 +37,7 @@
 #include <rtl/tencinfo.h>
 #include <tools/tenccvt.hxx>
 #include <osl/endian.h>
-#ifndef INCLUDED_I18NUTIL_UNICODE_HXX
 #include <i18nutil/unicode.hxx>	//unicode::getUnicodeScriptType
-#endif
 
 #include <vcl/metric.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
@@ -2094,3 +2093,5 @@ void WMFWriter::WriteEMFRecord( SvMemoryStream& rStream, sal_uInt32 nCurSize, sa
    rStream.SeekRel( nCurSize );
    UpdateRecordHeader();
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
