@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,9 +32,7 @@
 #include "productregistration.hxx"
 #include "unotools/regoptions.hxx"
 #include "registrationdlg.hxx"
-#ifndef _SVTOOLS_HRC
 #include <svtools/svtools.hrc>
-#endif
 #include "cppuhelper/factory.hxx"
 #include <cppuhelper/implbase1.hxx>
 #include <com/sun/star/lang/XInitialization.hpp>
@@ -505,3 +504,5 @@ SAL_DLLPUBLIC_EXPORT void * SAL_CALL component_getFactory (
 }
 
 } // extern "C"
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
