@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -61,6 +62,7 @@ using namespace com::sun::star::uno;
 #define FILTERCFG_ENABLE_EXCEL_PREVIEW  0x40000
 #define FILTERCFG_ENABLE_WORD_PREVIEW   0x80000
 #define FILTERCFG_USE_ENHANCED_FIELDS	0x100000
+#define FILTERCFG_WORD_WBCTBL			0x200000
 
 static SvtFilterOptions* pOptions=0;
 
@@ -149,6 +151,52 @@ void	SvtAppFilterOptions_Impl::Load()
         bSaveVBA = *(sal_Bool*)pValues[1].getValue();
 }
 
+// -----------------------------------------------------------------------
+class SvtWriterFilterOptions_Impl : public SvtAppFilterOptions_Impl
+{
+    sal_Bool				bLoadExecutable;
+public:
+    SvtWriterFilterOptions_Impl(const OUString& rRoot) :
+        SvtAppFilterOptions_Impl(rRoot),
+        bLoadExecutable(sal_False)
+    {}
+    virtual void			Commit();
+    void					Load();
+
+    sal_Bool				IsLoadExecutable() const {return bLoadExecutable;}
+    void					SetLoadExecutable(sal_Bool bSet)
+                            {
+                                if(bSet != bLoadExecutable)
+                                    SetModified();
+                                bLoadExecutable = bSet;
+                            }
+};
+
+void SvtWriterFilterOptions_Impl::Commit()
+{
+    SvtAppFilterOptions_Impl::Commit();
+
+    Sequence<OUString> aNames(1);
+    aNames[0] = C2U("Executable");
+    Sequence<Any> aValues(1);
+    aValues[0] <<= bLoadExecutable;
+
+    PutProperties(aNames, aValues);
+}
+
+void SvtWriterFilterOptions_Impl::Load()
+{
+    SvtAppFilterOptions_Impl::Load();
+
+    Sequence<OUString> aNames(1);
+    aNames[0] = C2U("Executable");
+
+    Sequence<Any> aValues = GetProperties(aNames);
+    const Any* pValues = aValues.getConstArray();
+    if(pValues[0].hasValue())
+        bLoadExecutable = *(sal_Bool*)pValues[0].getValue();
+}
+
 // -----------------------------------------------------------------------
 class SvtCalcFilterOptions_Impl : public SvtAppFilterOptions_Impl
 {
@@ -201,7 +249,7 @@ void SvtCalcFilterOptions_Impl::Load()
 struct SvtFilterOptions_Impl
 {
     ULONG nFlags;
-    SvtAppFilterOptions_Impl aWriterCfg;
+    SvtWriterFilterOptions_Impl	aWriterCfg;
     SvtCalcFilterOptions_Impl aCalcCfg;
     SvtAppFilterOptions_Impl aImpressCfg;
 
@@ -246,6 +294,7 @@ void SvtFilterOptions_Impl::SetFlag( ULONG nFlag, BOOL bSet )
     {
         case FILTERCFG_WORD_CODE:		aWriterCfg.SetLoad(bSet);break;
         case FILTERCFG_WORD_STORAGE:	aWriterCfg.SetSave(bSet);break;
+        case FILTERCFG_WORD_WBCTBL:	aWriterCfg.SetLoadExecutable(bSet);break;
         case FILTERCFG_EXCEL_CODE:		aCalcCfg.SetLoad(bSet);break;
         case FILTERCFG_EXCEL_STORAGE:	aCalcCfg.SetSave(bSet);break;
         case FILTERCFG_EXCEL_EXECTBL:	aCalcCfg.SetLoadExecutable(bSet);break;
@@ -268,6 +317,7 @@ BOOL SvtFilterOptions_Impl::IsFlag( ULONG nFlag ) const
     {
         case FILTERCFG_WORD_CODE 		: bRet = aWriterCfg.IsLoad();break;
         case FILTERCFG_WORD_STORAGE   	: bRet = aWriterCfg.IsSave();break;
+        case FILTERCFG_WORD_WBCTBL		: bRet = aWriterCfg.IsLoadExecutable();break;
         case FILTERCFG_EXCEL_CODE 	    : bRet = aCalcCfg.IsLoad();break;
         case FILTERCFG_EXCEL_STORAGE    : bRet = aCalcCfg.IsSave();break;
         case FILTERCFG_EXCEL_EXECTBL	: bRet = aCalcCfg.IsLoadExecutable();break;
@@ -399,106 +449,117 @@ void SvtFilterOptions::Load()
 }
 // -----------------------------------------------------------------------
 
-void SvtFilterOptions::SetLoadWordBasicCode( BOOL bFlag )
+void SvtFilterOptions::SetLoadWordBasicCode( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_WORD_CODE, bFlag );
     SetModified();
 }
 
-BOOL SvtFilterOptions::IsLoadWordBasicCode() const
+sal_Bool SvtFilterOptions::IsLoadWordBasicCode() const
 {
     return pImp->IsFlag( FILTERCFG_WORD_CODE );
 }
 
-void SvtFilterOptions::SetLoadWordBasicStorage( BOOL bFlag )
+void SvtFilterOptions::SetLoadWordBasicExecutable( sal_Bool bFlag )
+{
+    pImp->SetFlag( FILTERCFG_WORD_WBCTBL, bFlag );
+    SetModified();
+}
+
+BOOL SvtFilterOptions::IsLoadWordBasicExecutable() const
+{
+    return pImp->IsFlag( FILTERCFG_WORD_WBCTBL );
+}
+
+void SvtFilterOptions::SetLoadWordBasicStorage( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_WORD_STORAGE, bFlag );
     SetModified();
 }
 
-BOOL SvtFilterOptions::IsLoadWordBasicStorage() const
+sal_Bool SvtFilterOptions::IsLoadWordBasicStorage() const
 {
     return pImp->IsFlag( FILTERCFG_WORD_STORAGE );
 }
 
 // -----------------------------------------------------------------------
 
-void SvtFilterOptions::SetLoadExcelBasicCode( BOOL bFlag )
+void SvtFilterOptions::SetLoadExcelBasicCode( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_EXCEL_CODE, bFlag );
     SetModified();
 }
 
-BOOL SvtFilterOptions::IsLoadExcelBasicCode() const
+sal_Bool SvtFilterOptions::IsLoadExcelBasicCode() const
 {
     return pImp->IsFlag( FILTERCFG_EXCEL_CODE );
 }
 
-void SvtFilterOptions::SetLoadExcelBasicExecutable( BOOL bFlag )
+void SvtFilterOptions::SetLoadExcelBasicExecutable( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_EXCEL_EXECTBL, bFlag );
     SetModified();
 }
 
-BOOL SvtFilterOptions::IsLoadExcelBasicExecutable() const
+sal_Bool SvtFilterOptions::IsLoadExcelBasicExecutable() const
 {
     return pImp->IsFlag( FILTERCFG_EXCEL_EXECTBL );
 }
 
-void SvtFilterOptions::SetLoadExcelBasicStorage( BOOL bFlag )
+void SvtFilterOptions::SetLoadExcelBasicStorage( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_EXCEL_STORAGE, bFlag );
     SetModified();
 }
 
-BOOL SvtFilterOptions::IsLoadExcelBasicStorage() const
+sal_Bool SvtFilterOptions::IsLoadExcelBasicStorage() const
 {
     return pImp->IsFlag( FILTERCFG_EXCEL_STORAGE );
 }
 
 // -----------------------------------------------------------------------
 
-void SvtFilterOptions::SetLoadPPointBasicCode( BOOL bFlag )
+void SvtFilterOptions::SetLoadPPointBasicCode( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_PPOINT_CODE, bFlag );
     SetModified();
 }
 
-BOOL SvtFilterOptions::IsLoadPPointBasicCode() const
+sal_Bool SvtFilterOptions::IsLoadPPointBasicCode() const
 {
     return pImp->IsFlag( FILTERCFG_PPOINT_CODE );
 }
 
-void SvtFilterOptions::SetLoadPPointBasicStorage( BOOL bFlag )
+void SvtFilterOptions::SetLoadPPointBasicStorage( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_PPOINT_STORAGE, bFlag );
     SetModified();
 }
 
-BOOL SvtFilterOptions::IsLoadPPointBasicStorage() const
+sal_Bool SvtFilterOptions::IsLoadPPointBasicStorage() const
 {
     return pImp->IsFlag( FILTERCFG_PPOINT_STORAGE );
 }
 
 // -----------------------------------------------------------------------
 
-BOOL SvtFilterOptions::IsMathType2Math() const
+sal_Bool SvtFilterOptions::IsMathType2Math() const
 {
     return pImp->IsFlag( FILTERCFG_MATH_LOAD );
 }
 
-void SvtFilterOptions::SetMathType2Math( BOOL bFlag )
+void SvtFilterOptions::SetMathType2Math( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_MATH_LOAD, bFlag );
     SetModified();
 }
 
-BOOL SvtFilterOptions::IsMath2MathType() const
+sal_Bool SvtFilterOptions::IsMath2MathType() const
 {
     return pImp->IsFlag( FILTERCFG_MATH_SAVE );
 }
 
-void SvtFilterOptions::SetMath2MathType( BOOL bFlag )
+void SvtFilterOptions::SetMath2MathType( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_MATH_SAVE, bFlag );
     SetModified();
@@ -506,57 +567,57 @@ void SvtFilterOptions::SetMath2MathType( BOOL bFlag )
 
 
 // -----------------------------------------------------------------------
-BOOL SvtFilterOptions::IsWinWord2Writer() const
+sal_Bool SvtFilterOptions::IsWinWord2Writer() const
 {
     return pImp->IsFlag( FILTERCFG_WRITER_LOAD );
 }
 
-void SvtFilterOptions::SetWinWord2Writer( BOOL bFlag )
+void SvtFilterOptions::SetWinWord2Writer( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_WRITER_LOAD, bFlag );
     SetModified();
 }
 
-BOOL SvtFilterOptions::IsWriter2WinWord() const
+sal_Bool SvtFilterOptions::IsWriter2WinWord() const
 {
     return pImp->IsFlag( FILTERCFG_WRITER_SAVE );
 }
 
-void SvtFilterOptions::SetWriter2WinWord( BOOL bFlag )
+void SvtFilterOptions::SetWriter2WinWord( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_WRITER_SAVE, bFlag );
     SetModified();
 }
 
-BOOL SvtFilterOptions::IsUseEnhancedFields() const
+sal_Bool SvtFilterOptions::IsUseEnhancedFields() const
 {
     return pImp->IsFlag( FILTERCFG_USE_ENHANCED_FIELDS );
 }
 
-void SvtFilterOptions::SetUseEnhancedFields( BOOL bFlag )
+void SvtFilterOptions::SetUseEnhancedFields( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_USE_ENHANCED_FIELDS, bFlag );
     SetModified();
 }
 
 // -----------------------------------------------------------------------
-BOOL SvtFilterOptions::IsExcel2Calc() const
+sal_Bool SvtFilterOptions::IsExcel2Calc() const
 {
     return pImp->IsFlag( FILTERCFG_CALC_LOAD );
 }
 
-void SvtFilterOptions::SetExcel2Calc( BOOL bFlag )
+void SvtFilterOptions::SetExcel2Calc( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_CALC_LOAD, bFlag );
     SetModified();
 }
 
-BOOL SvtFilterOptions::IsCalc2Excel() const
+sal_Bool SvtFilterOptions::IsCalc2Excel() const
 {
     return pImp->IsFlag( FILTERCFG_CALC_SAVE );
 }
 
-void SvtFilterOptions::SetCalc2Excel( BOOL bFlag )
+void SvtFilterOptions::SetCalc2Excel( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_CALC_SAVE, bFlag );
     SetModified();
@@ -564,23 +625,23 @@ void SvtFilterOptions::SetCalc2Excel( BOOL bFlag )
 
 
 // -----------------------------------------------------------------------
-BOOL SvtFilterOptions::IsPowerPoint2Impress() const
+sal_Bool SvtFilterOptions::IsPowerPoint2Impress() const
 {
     return pImp->IsFlag( FILTERCFG_IMPRESS_LOAD );
 }
 
-void SvtFilterOptions::SetPowerPoint2Impress( BOOL bFlag )
+void SvtFilterOptions::SetPowerPoint2Impress( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_IMPRESS_LOAD, bFlag );
     SetModified();
 }
 
-BOOL SvtFilterOptions::IsImpress2PowerPoint() const
+sal_Bool SvtFilterOptions::IsImpress2PowerPoint() const
 {
     return pImp->IsFlag( FILTERCFG_IMPRESS_SAVE );
 }
 
-void SvtFilterOptions::SetImpress2PowerPoint( BOOL bFlag )
+void SvtFilterOptions::SetImpress2PowerPoint( sal_Bool bFlag )
 {
     pImp->SetFlag( FILTERCFG_IMPRESS_SAVE, bFlag );
     SetModified();
@@ -595,21 +656,22 @@ SvtFilterOptions* SvtFilterOptions::Get()
 
 // -----------------------------------------------------------------------
 
-BOOL SvtFilterOptions::IsEnablePPTPreview() const
+sal_Bool SvtFilterOptions::IsEnablePPTPreview() const
 {
     return pImp->IsFlag( FILTERCFG_ENABLE_PPT_PREVIEW );
 }
 
 
-BOOL SvtFilterOptions::IsEnableCalcPreview() const
+sal_Bool SvtFilterOptions::IsEnableCalcPreview() const
 {
     return pImp->IsFlag( FILTERCFG_ENABLE_EXCEL_PREVIEW );
 }
 
 
-BOOL SvtFilterOptions::IsEnableWordPreview() const
+sal_Bool SvtFilterOptions::IsEnableWordPreview() const
 {
     return pImp->IsFlag( FILTERCFG_ENABLE_WORD_PREVIEW );
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
