@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,9 +31,7 @@
 #include <unotools/inetoptions.hxx>
 #include "rtl/instance.hxx"
 #include <tools/urlobj.hxx>
-#ifndef _WILDCARD_HXX
 #include <tools/wldcrd.hxx>
-#endif
 
 #include <algorithm>
 #include <map>
@@ -552,3 +551,5 @@ SvtInetOptions::removePropertiesChangeListener(
 {
     m_pImpl->removePropertiesChangeListener(rPropertyNames, rListener);
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
