@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -37,6 +38,7 @@
 #include "vcl/salptype.hxx"
 #include "vcl/print.hxx"
 #include "vcl/unohelp.hxx"
+#include <sal/macros.h>
 
 #include <boost/bind.hpp>
 
@@ -103,12 +105,6 @@ AquaSalInfoPrinter::~AquaSalInfoPrinter()
     delete mpGraphics;
     if( mpPrintInfo )
         [mpPrintInfo release];
-    #if 0
-    // FIXME: verify that NSPrintInfo releases the printer
-    // else we have a leak here
-    if( mpPrinter )
-        [mpPrinter release];
-    #endif
     if( mrContext )
         CFRelease( mrContext );
 }
@@ -202,7 +198,7 @@ static struct PaperSizeEntry
 
 static bool getPaperSize( double& o_fWidth, double& o_fHeight, const Paper i_ePaper )
 {
-    for(unsigned int i = 0; i < sizeof(aPaperSizes)/sizeof(aPaperSizes[0]); i++ )
+    for(unsigned int i = 0; i < SAL_N_ELEMENTS(aPaperSizes); i++ )
     {
         if( aPaperSizes[i].nPaper == i_ePaper )
         {
@@ -236,7 +232,7 @@ static Paper recognizePaper( double i_fWidth, double i_fHeight )
     if( aPaper == PAPER_USER )
     {
         // search with fuzz factor
-        for( unsigned int i = 0; i < sizeof(aPaperSizes)/sizeof(aPaperSizes[0]); i++ )
+        for( unsigned int i = 0; i < SAL_N_ELEMENTS(aPaperSizes); i++ )
         {
             double w = (i_fWidth > aPaperSizes[i].fWidth) ? i_fWidth - aPaperSizes[i].fWidth : aPaperSizes[i].fWidth - i_fWidth;
             double h = (i_fHeight > aPaperSizes[i].fHeight) ? i_fHeight - aPaperSizes[i].fHeight : aPaperSizes[i].fHeight - i_fHeight;
@@ -875,3 +871,4 @@ int AquaSalInfoPrinter::GetLandscapeAngle( const ImplJobSetup* i_pSetupData )
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
