@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -554,15 +555,4 @@ const SystemChildData* Os2SalObject::GetSystemData() const
     return &maSysData;
 }
 
-// -----------------------------------------------------------------------
-#if 0
-void Os2SalObject::SetCallback( void* pInst, SALOBJECTPROC pProc )
-{
-    mpInst = pInst;
-    if ( pProc )
-        mpProc = pProc;
-    else
-        mpProc = ImplSalObjCallbackDummy;
-}
-#endif
-
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
