@@ -1472,7 +1472,7 @@ SystemGraphicsData PspGraphics::GetGraphicsData() const
     SystemGraphicsData aRes;
     aRes.nSize = sizeof(aRes);
         aRes.hDrawable = 0;
-        aRes.pRenderFormat = 0;
+        aRes.pXRenderFormat = 0;
     return aRes;
 }
 
