@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,9 +31,7 @@
 
 #include <string.h>
 
-#ifndef _SVWIN_HXX
 #include <tools/svwin.h>
-#endif
 #include <wincomp.hxx>
 #include <saldata.hxx>
 #include <salinst.h>
@@ -836,3 +835,5 @@ const SystemEnvData* WinSalObject::GetSystemData() const
 {
     return &maSysData;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
